Documentation
¶
Overview ¶
Package store provides local file storage for CLI data
Index ¶
- func AcquireLock(lockPath string) (func(), error)
- func GetConfigDir() (string, error)
- func GetDebugPath(profile string) (string, error)
- func GetServerURLPath(profile string) (string, error)
- func GetTokenPath(profile string) (string, error)
- func LoadDebug(profile string) (bool, error)
- func LoadServerURL(profile string) (string, error)
- func LoadToken(profile string) (string, error)
- func SaveDebug(enabled bool, profile string) error
- func SaveServerURL(serverURL, profile string) error
- func SaveToken(token, profile string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AcquireLock ¶
AcquireLock creates a lock file for concurrent access
func GetConfigDir ¶
GetConfigDir returns the configuration directory path
func GetDebugPath ¶
GetDebugPath returns the path to the debug config file.
func GetServerURLPath ¶
GetServerURLPath returns the path to the server URL file
func GetTokenPath ¶
GetTokenPath returns the path to the token file
func LoadDebug ¶
LoadDebug loads the debug mode setting. Returns false if the setting has never been saved.
func LoadServerURL ¶
LoadServerURL loads the server URL
func SaveServerURL ¶
SaveServerURL saves the server URL
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.