agentmemoryfact

package
v0.99.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 17, 2026 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the agentmemoryfact type in the database.
	Label = "agent_memory_fact"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldScope holds the string denoting the scope field in the database.
	FieldScope = "scope"
	// FieldKey holds the string denoting the key field in the database.
	FieldKey = "key"
	// FieldValue holds the string denoting the value field in the database.
	FieldValue = "value"
	// FieldPinned holds the string denoting the pinned field in the database.
	FieldPinned = "pinned"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// Table holds the table name of the agentmemoryfact in the database.
	Table = "agent_memory_facts"
)

Variables

var (
	// ScopeValidator is a validator for the "scope" field. It is called by the builders before save.
	ScopeValidator func(string) error
	// KeyValidator is a validator for the "key" field. It is called by the builders before save.
	KeyValidator func(string) error
	// ValueValidator is a validator for the "value" field. It is called by the builders before save.
	ValueValidator func(string) error
	// DefaultPinned holds the default value on creation for the "pinned" field.
	DefaultPinned bool
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
)

Columns holds all SQL columns for agentmemoryfact fields.

Functions

func And

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.AgentMemoryFact

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.AgentMemoryFact

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.AgentMemoryFact

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.AgentMemoryFact

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.AgentMemoryFact

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.AgentMemoryFact

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.AgentMemoryFact

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.AgentMemoryFact

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.AgentMemoryFact

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int64) predicate.AgentMemoryFact

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int64) predicate.AgentMemoryFact

IDNotIn applies the NotIn predicate on the ID field.

func Key

Key applies equality check predicate on the "key" field. It's identical to KeyEQ.

func KeyContains

func KeyContains(v string) predicate.AgentMemoryFact

KeyContains applies the Contains predicate on the "key" field.

func KeyContainsFold

func KeyContainsFold(v string) predicate.AgentMemoryFact

KeyContainsFold applies the ContainsFold predicate on the "key" field.

func KeyEQ

KeyEQ applies the EQ predicate on the "key" field.

func KeyEqualFold

func KeyEqualFold(v string) predicate.AgentMemoryFact

KeyEqualFold applies the EqualFold predicate on the "key" field.

func KeyGT

KeyGT applies the GT predicate on the "key" field.

func KeyGTE

KeyGTE applies the GTE predicate on the "key" field.

func KeyHasPrefix

func KeyHasPrefix(v string) predicate.AgentMemoryFact

KeyHasPrefix applies the HasPrefix predicate on the "key" field.

func KeyHasSuffix

func KeyHasSuffix(v string) predicate.AgentMemoryFact

KeyHasSuffix applies the HasSuffix predicate on the "key" field.

func KeyIn

func KeyIn(vs ...string) predicate.AgentMemoryFact

KeyIn applies the In predicate on the "key" field.

func KeyLT

KeyLT applies the LT predicate on the "key" field.

func KeyLTE

KeyLTE applies the LTE predicate on the "key" field.

func KeyNEQ

KeyNEQ applies the NEQ predicate on the "key" field.

func KeyNotIn

func KeyNotIn(vs ...string) predicate.AgentMemoryFact

KeyNotIn applies the NotIn predicate on the "key" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func Pinned

func Pinned(v bool) predicate.AgentMemoryFact

Pinned applies equality check predicate on the "pinned" field. It's identical to PinnedEQ.

func PinnedEQ

func PinnedEQ(v bool) predicate.AgentMemoryFact

PinnedEQ applies the EQ predicate on the "pinned" field.

func PinnedNEQ

func PinnedNEQ(v bool) predicate.AgentMemoryFact

PinnedNEQ applies the NEQ predicate on the "pinned" field.

func Scope

Scope applies equality check predicate on the "scope" field. It's identical to ScopeEQ.

func ScopeContains

func ScopeContains(v string) predicate.AgentMemoryFact

ScopeContains applies the Contains predicate on the "scope" field.

func ScopeContainsFold

func ScopeContainsFold(v string) predicate.AgentMemoryFact

ScopeContainsFold applies the ContainsFold predicate on the "scope" field.

func ScopeEQ

func ScopeEQ(v string) predicate.AgentMemoryFact

ScopeEQ applies the EQ predicate on the "scope" field.

func ScopeEqualFold

func ScopeEqualFold(v string) predicate.AgentMemoryFact

ScopeEqualFold applies the EqualFold predicate on the "scope" field.

func ScopeGT

func ScopeGT(v string) predicate.AgentMemoryFact

ScopeGT applies the GT predicate on the "scope" field.

func ScopeGTE

func ScopeGTE(v string) predicate.AgentMemoryFact

ScopeGTE applies the GTE predicate on the "scope" field.

func ScopeHasPrefix

func ScopeHasPrefix(v string) predicate.AgentMemoryFact

ScopeHasPrefix applies the HasPrefix predicate on the "scope" field.

func ScopeHasSuffix

func ScopeHasSuffix(v string) predicate.AgentMemoryFact

ScopeHasSuffix applies the HasSuffix predicate on the "scope" field.

func ScopeIn

func ScopeIn(vs ...string) predicate.AgentMemoryFact

ScopeIn applies the In predicate on the "scope" field.

func ScopeLT

func ScopeLT(v string) predicate.AgentMemoryFact

ScopeLT applies the LT predicate on the "scope" field.

func ScopeLTE

func ScopeLTE(v string) predicate.AgentMemoryFact

ScopeLTE applies the LTE predicate on the "scope" field.

func ScopeNEQ

func ScopeNEQ(v string) predicate.AgentMemoryFact

ScopeNEQ applies the NEQ predicate on the "scope" field.

func ScopeNotIn

func ScopeNotIn(vs ...string) predicate.AgentMemoryFact

ScopeNotIn applies the NotIn predicate on the "scope" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.AgentMemoryFact

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.AgentMemoryFact

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.AgentMemoryFact

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.AgentMemoryFact

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.AgentMemoryFact

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.AgentMemoryFact

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.AgentMemoryFact

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.AgentMemoryFact

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.AgentMemoryFact

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Value

Value applies equality check predicate on the "value" field. It's identical to ValueEQ.

func ValueContains

func ValueContains(v string) predicate.AgentMemoryFact

ValueContains applies the Contains predicate on the "value" field.

func ValueContainsFold

func ValueContainsFold(v string) predicate.AgentMemoryFact

ValueContainsFold applies the ContainsFold predicate on the "value" field.

func ValueEQ

func ValueEQ(v string) predicate.AgentMemoryFact

ValueEQ applies the EQ predicate on the "value" field.

func ValueEqualFold

func ValueEqualFold(v string) predicate.AgentMemoryFact

ValueEqualFold applies the EqualFold predicate on the "value" field.

func ValueGT

func ValueGT(v string) predicate.AgentMemoryFact

ValueGT applies the GT predicate on the "value" field.

func ValueGTE

func ValueGTE(v string) predicate.AgentMemoryFact

ValueGTE applies the GTE predicate on the "value" field.

func ValueHasPrefix

func ValueHasPrefix(v string) predicate.AgentMemoryFact

ValueHasPrefix applies the HasPrefix predicate on the "value" field.

func ValueHasSuffix

func ValueHasSuffix(v string) predicate.AgentMemoryFact

ValueHasSuffix applies the HasSuffix predicate on the "value" field.

func ValueIn

func ValueIn(vs ...string) predicate.AgentMemoryFact

ValueIn applies the In predicate on the "value" field.

func ValueLT

func ValueLT(v string) predicate.AgentMemoryFact

ValueLT applies the LT predicate on the "value" field.

func ValueLTE

func ValueLTE(v string) predicate.AgentMemoryFact

ValueLTE applies the LTE predicate on the "value" field.

func ValueNEQ

func ValueNEQ(v string) predicate.AgentMemoryFact

ValueNEQ applies the NEQ predicate on the "value" field.

func ValueNotIn

func ValueNotIn(vs ...string) predicate.AgentMemoryFact

ValueNotIn applies the NotIn predicate on the "value" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the AgentMemoryFact queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByKey

func ByKey(opts ...sql.OrderTermOption) OrderOption

ByKey orders the results by the key field.

func ByPinned

func ByPinned(opts ...sql.OrderTermOption) OrderOption

ByPinned orders the results by the pinned field.

func ByScope

func ByScope(opts ...sql.OrderTermOption) OrderOption

ByScope orders the results by the scope field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByValue

func ByValue(opts ...sql.OrderTermOption) OrderOption

ByValue orders the results by the value field.

Jump to