app

package
v0.99.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 17, 2026 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the app type in the database.
	Label = "app"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldPath holds the string denoting the path field in the database.
	FieldPath = "path"
	// FieldContainerID holds the string denoting the container_id field in the database.
	FieldContainerID = "container_id"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// FieldDockerInfo holds the string denoting the docker_info field in the database.
	FieldDockerInfo = "docker_info"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// Table holds the table name of the app in the database.
	Table = "apps"
)

Variables

var (
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// PathValidator is a validator for the "path" field. It is called by the builders before save.
	PathValidator func(string) error
	// DefaultContainerID holds the default value on creation for the "container_id" field.
	DefaultContainerID string
	// DefaultStatus holds the default value on creation for the "status" field.
	DefaultStatus string
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
)

Columns holds all SQL columns for app fields.

Functions

func And

func And(predicates ...predicate.App) predicate.App

And groups predicates with the AND operator between them.

func ContainerID

func ContainerID(v string) predicate.App

ContainerID applies equality check predicate on the "container_id" field. It's identical to ContainerIDEQ.

func ContainerIDContains

func ContainerIDContains(v string) predicate.App

ContainerIDContains applies the Contains predicate on the "container_id" field.

func ContainerIDContainsFold

func ContainerIDContainsFold(v string) predicate.App

ContainerIDContainsFold applies the ContainsFold predicate on the "container_id" field.

func ContainerIDEQ

func ContainerIDEQ(v string) predicate.App

ContainerIDEQ applies the EQ predicate on the "container_id" field.

func ContainerIDEqualFold

func ContainerIDEqualFold(v string) predicate.App

ContainerIDEqualFold applies the EqualFold predicate on the "container_id" field.

func ContainerIDGT

func ContainerIDGT(v string) predicate.App

ContainerIDGT applies the GT predicate on the "container_id" field.

func ContainerIDGTE

func ContainerIDGTE(v string) predicate.App

ContainerIDGTE applies the GTE predicate on the "container_id" field.

func ContainerIDHasPrefix

func ContainerIDHasPrefix(v string) predicate.App

ContainerIDHasPrefix applies the HasPrefix predicate on the "container_id" field.

func ContainerIDHasSuffix

func ContainerIDHasSuffix(v string) predicate.App

ContainerIDHasSuffix applies the HasSuffix predicate on the "container_id" field.

func ContainerIDIn

func ContainerIDIn(vs ...string) predicate.App

ContainerIDIn applies the In predicate on the "container_id" field.

func ContainerIDIsNil

func ContainerIDIsNil() predicate.App

ContainerIDIsNil applies the IsNil predicate on the "container_id" field.

func ContainerIDLT

func ContainerIDLT(v string) predicate.App

ContainerIDLT applies the LT predicate on the "container_id" field.

func ContainerIDLTE

func ContainerIDLTE(v string) predicate.App

ContainerIDLTE applies the LTE predicate on the "container_id" field.

func ContainerIDNEQ

func ContainerIDNEQ(v string) predicate.App

ContainerIDNEQ applies the NEQ predicate on the "container_id" field.

func ContainerIDNotIn

func ContainerIDNotIn(vs ...string) predicate.App

ContainerIDNotIn applies the NotIn predicate on the "container_id" field.

func ContainerIDNotNil

func ContainerIDNotNil() predicate.App

ContainerIDNotNil applies the NotNil predicate on the "container_id" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.App

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.App

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.App

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.App

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.App

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.App

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.App

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.App

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.App

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DockerInfoIsNil

func DockerInfoIsNil() predicate.App

DockerInfoIsNil applies the IsNil predicate on the "docker_info" field.

func DockerInfoNotNil

func DockerInfoNotNil() predicate.App

DockerInfoNotNil applies the NotNil predicate on the "docker_info" field.

func ID

func ID(id int64) predicate.App

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int64) predicate.App

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int64) predicate.App

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int64) predicate.App

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int64) predicate.App

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int64) predicate.App

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int64) predicate.App

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int64) predicate.App

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int64) predicate.App

IDNotIn applies the NotIn predicate on the ID field.

func Name

func Name(v string) predicate.App

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.App

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.App

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.App

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.App

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.App

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.App

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.App

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.App

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.App

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.App

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.App

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.App

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.App

NameNotIn applies the NotIn predicate on the "name" field.

func Not

func Not(p predicate.App) predicate.App

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.App) predicate.App

Or groups predicates with the OR operator between them.

func Path

func Path(v string) predicate.App

Path applies equality check predicate on the "path" field. It's identical to PathEQ.

func PathContains

func PathContains(v string) predicate.App

PathContains applies the Contains predicate on the "path" field.

func PathContainsFold

func PathContainsFold(v string) predicate.App

PathContainsFold applies the ContainsFold predicate on the "path" field.

func PathEQ

func PathEQ(v string) predicate.App

PathEQ applies the EQ predicate on the "path" field.

func PathEqualFold

func PathEqualFold(v string) predicate.App

PathEqualFold applies the EqualFold predicate on the "path" field.

func PathGT

func PathGT(v string) predicate.App

PathGT applies the GT predicate on the "path" field.

func PathGTE

func PathGTE(v string) predicate.App

PathGTE applies the GTE predicate on the "path" field.

func PathHasPrefix

func PathHasPrefix(v string) predicate.App

PathHasPrefix applies the HasPrefix predicate on the "path" field.

func PathHasSuffix

func PathHasSuffix(v string) predicate.App

PathHasSuffix applies the HasSuffix predicate on the "path" field.

func PathIn

func PathIn(vs ...string) predicate.App

PathIn applies the In predicate on the "path" field.

func PathLT

func PathLT(v string) predicate.App

PathLT applies the LT predicate on the "path" field.

func PathLTE

func PathLTE(v string) predicate.App

PathLTE applies the LTE predicate on the "path" field.

func PathNEQ

func PathNEQ(v string) predicate.App

PathNEQ applies the NEQ predicate on the "path" field.

func PathNotIn

func PathNotIn(vs ...string) predicate.App

PathNotIn applies the NotIn predicate on the "path" field.

func Status

func Status(v string) predicate.App

Status applies equality check predicate on the "status" field. It's identical to StatusEQ.

func StatusContains

func StatusContains(v string) predicate.App

StatusContains applies the Contains predicate on the "status" field.

func StatusContainsFold

func StatusContainsFold(v string) predicate.App

StatusContainsFold applies the ContainsFold predicate on the "status" field.

func StatusEQ

func StatusEQ(v string) predicate.App

StatusEQ applies the EQ predicate on the "status" field.

func StatusEqualFold

func StatusEqualFold(v string) predicate.App

StatusEqualFold applies the EqualFold predicate on the "status" field.

func StatusGT

func StatusGT(v string) predicate.App

StatusGT applies the GT predicate on the "status" field.

func StatusGTE

func StatusGTE(v string) predicate.App

StatusGTE applies the GTE predicate on the "status" field.

func StatusHasPrefix

func StatusHasPrefix(v string) predicate.App

StatusHasPrefix applies the HasPrefix predicate on the "status" field.

func StatusHasSuffix

func StatusHasSuffix(v string) predicate.App

StatusHasSuffix applies the HasSuffix predicate on the "status" field.

func StatusIn

func StatusIn(vs ...string) predicate.App

StatusIn applies the In predicate on the "status" field.

func StatusLT

func StatusLT(v string) predicate.App

StatusLT applies the LT predicate on the "status" field.

func StatusLTE

func StatusLTE(v string) predicate.App

StatusLTE applies the LTE predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v string) predicate.App

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...string) predicate.App

StatusNotIn applies the NotIn predicate on the "status" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.App

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.App

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.App

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.App

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.App

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.App

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.App

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.App

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.App

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the App queries.

func ByContainerID

func ByContainerID(opts ...sql.OrderTermOption) OrderOption

ByContainerID orders the results by the container_id field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByPath

func ByPath(opts ...sql.OrderTermOption) OrderOption

ByPath orders the results by the path field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

Jump to