Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.App) predicate.App
- func ContainerID(v string) predicate.App
- func ContainerIDContains(v string) predicate.App
- func ContainerIDContainsFold(v string) predicate.App
- func ContainerIDEQ(v string) predicate.App
- func ContainerIDEqualFold(v string) predicate.App
- func ContainerIDGT(v string) predicate.App
- func ContainerIDGTE(v string) predicate.App
- func ContainerIDHasPrefix(v string) predicate.App
- func ContainerIDHasSuffix(v string) predicate.App
- func ContainerIDIn(vs ...string) predicate.App
- func ContainerIDIsNil() predicate.App
- func ContainerIDLT(v string) predicate.App
- func ContainerIDLTE(v string) predicate.App
- func ContainerIDNEQ(v string) predicate.App
- func ContainerIDNotIn(vs ...string) predicate.App
- func ContainerIDNotNil() predicate.App
- func CreatedAt(v time.Time) predicate.App
- func CreatedAtEQ(v time.Time) predicate.App
- func CreatedAtGT(v time.Time) predicate.App
- func CreatedAtGTE(v time.Time) predicate.App
- func CreatedAtIn(vs ...time.Time) predicate.App
- func CreatedAtLT(v time.Time) predicate.App
- func CreatedAtLTE(v time.Time) predicate.App
- func CreatedAtNEQ(v time.Time) predicate.App
- func CreatedAtNotIn(vs ...time.Time) predicate.App
- func DockerInfoIsNil() predicate.App
- func DockerInfoNotNil() predicate.App
- func ID(id int64) predicate.App
- func IDEQ(id int64) predicate.App
- func IDGT(id int64) predicate.App
- func IDGTE(id int64) predicate.App
- func IDIn(ids ...int64) predicate.App
- func IDLT(id int64) predicate.App
- func IDLTE(id int64) predicate.App
- func IDNEQ(id int64) predicate.App
- func IDNotIn(ids ...int64) predicate.App
- func Name(v string) predicate.App
- func NameContains(v string) predicate.App
- func NameContainsFold(v string) predicate.App
- func NameEQ(v string) predicate.App
- func NameEqualFold(v string) predicate.App
- func NameGT(v string) predicate.App
- func NameGTE(v string) predicate.App
- func NameHasPrefix(v string) predicate.App
- func NameHasSuffix(v string) predicate.App
- func NameIn(vs ...string) predicate.App
- func NameLT(v string) predicate.App
- func NameLTE(v string) predicate.App
- func NameNEQ(v string) predicate.App
- func NameNotIn(vs ...string) predicate.App
- func Not(p predicate.App) predicate.App
- func Or(predicates ...predicate.App) predicate.App
- func Path(v string) predicate.App
- func PathContains(v string) predicate.App
- func PathContainsFold(v string) predicate.App
- func PathEQ(v string) predicate.App
- func PathEqualFold(v string) predicate.App
- func PathGT(v string) predicate.App
- func PathGTE(v string) predicate.App
- func PathHasPrefix(v string) predicate.App
- func PathHasSuffix(v string) predicate.App
- func PathIn(vs ...string) predicate.App
- func PathLT(v string) predicate.App
- func PathLTE(v string) predicate.App
- func PathNEQ(v string) predicate.App
- func PathNotIn(vs ...string) predicate.App
- func Status(v string) predicate.App
- func StatusContains(v string) predicate.App
- func StatusContainsFold(v string) predicate.App
- func StatusEQ(v string) predicate.App
- func StatusEqualFold(v string) predicate.App
- func StatusGT(v string) predicate.App
- func StatusGTE(v string) predicate.App
- func StatusHasPrefix(v string) predicate.App
- func StatusHasSuffix(v string) predicate.App
- func StatusIn(vs ...string) predicate.App
- func StatusLT(v string) predicate.App
- func StatusLTE(v string) predicate.App
- func StatusNEQ(v string) predicate.App
- func StatusNotIn(vs ...string) predicate.App
- func UpdatedAt(v time.Time) predicate.App
- func UpdatedAtEQ(v time.Time) predicate.App
- func UpdatedAtGT(v time.Time) predicate.App
- func UpdatedAtGTE(v time.Time) predicate.App
- func UpdatedAtIn(vs ...time.Time) predicate.App
- func UpdatedAtLT(v time.Time) predicate.App
- func UpdatedAtLTE(v time.Time) predicate.App
- func UpdatedAtNEQ(v time.Time) predicate.App
- func UpdatedAtNotIn(vs ...time.Time) predicate.App
- func ValidColumn(column string) bool
- type OrderOption
- func ByContainerID(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByPath(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the app type in the database. Label = "app" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldPath holds the string denoting the path field in the database. FieldPath = "path" // FieldContainerID holds the string denoting the container_id field in the database. FieldContainerID = "container_id" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldDockerInfo holds the string denoting the docker_info field in the database. FieldDockerInfo = "docker_info" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // Table holds the table name of the app in the database. Table = "apps" )
Variables ¶
var ( // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // PathValidator is a validator for the "path" field. It is called by the builders before save. PathValidator func(string) error // DefaultContainerID holds the default value on creation for the "container_id" field. DefaultContainerID string // DefaultStatus holds the default value on creation for the "status" field. DefaultStatus string // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time )
var Columns = []string{ FieldID, FieldName, FieldPath, FieldContainerID, FieldStatus, FieldDockerInfo, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for app fields.
Functions ¶
func ContainerID ¶
ContainerID applies equality check predicate on the "container_id" field. It's identical to ContainerIDEQ.
func ContainerIDContains ¶
ContainerIDContains applies the Contains predicate on the "container_id" field.
func ContainerIDContainsFold ¶
ContainerIDContainsFold applies the ContainsFold predicate on the "container_id" field.
func ContainerIDEQ ¶
ContainerIDEQ applies the EQ predicate on the "container_id" field.
func ContainerIDEqualFold ¶
ContainerIDEqualFold applies the EqualFold predicate on the "container_id" field.
func ContainerIDGT ¶
ContainerIDGT applies the GT predicate on the "container_id" field.
func ContainerIDGTE ¶
ContainerIDGTE applies the GTE predicate on the "container_id" field.
func ContainerIDHasPrefix ¶
ContainerIDHasPrefix applies the HasPrefix predicate on the "container_id" field.
func ContainerIDHasSuffix ¶
ContainerIDHasSuffix applies the HasSuffix predicate on the "container_id" field.
func ContainerIDIn ¶
ContainerIDIn applies the In predicate on the "container_id" field.
func ContainerIDIsNil ¶
ContainerIDIsNil applies the IsNil predicate on the "container_id" field.
func ContainerIDLT ¶
ContainerIDLT applies the LT predicate on the "container_id" field.
func ContainerIDLTE ¶
ContainerIDLTE applies the LTE predicate on the "container_id" field.
func ContainerIDNEQ ¶
ContainerIDNEQ applies the NEQ predicate on the "container_id" field.
func ContainerIDNotIn ¶
ContainerIDNotIn applies the NotIn predicate on the "container_id" field.
func ContainerIDNotNil ¶
ContainerIDNotNil applies the NotNil predicate on the "container_id" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func DockerInfoIsNil ¶
DockerInfoIsNil applies the IsNil predicate on the "docker_info" field.
func DockerInfoNotNil ¶
DockerInfoNotNil applies the NotNil predicate on the "docker_info" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func PathContains ¶
PathContains applies the Contains predicate on the "path" field.
func PathContainsFold ¶
PathContainsFold applies the ContainsFold predicate on the "path" field.
func PathEqualFold ¶
PathEqualFold applies the EqualFold predicate on the "path" field.
func PathHasPrefix ¶
PathHasPrefix applies the HasPrefix predicate on the "path" field.
func PathHasSuffix ¶
PathHasSuffix applies the HasSuffix predicate on the "path" field.
func Status ¶
Status applies equality check predicate on the "status" field. It's identical to StatusEQ.
func StatusContains ¶
StatusContains applies the Contains predicate on the "status" field.
func StatusContainsFold ¶
StatusContainsFold applies the ContainsFold predicate on the "status" field.
func StatusEqualFold ¶
StatusEqualFold applies the EqualFold predicate on the "status" field.
func StatusHasPrefix ¶
StatusHasPrefix applies the HasPrefix predicate on the "status" field.
func StatusHasSuffix ¶
StatusHasSuffix applies the HasSuffix predicate on the "status" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the App queries.
func ByContainerID ¶
func ByContainerID(opts ...sql.OrderTermOption) OrderOption
ByContainerID orders the results by the container_id field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByPath ¶
func ByPath(opts ...sql.OrderTermOption) OrderOption
ByPath orders the results by the path field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.