Documentation
¶
Overview ¶
Package notify provides the chatagent tool for Gateway notification pushes.
Index ¶
Constants ¶
const (
// SendToolName is the agent tool name for sending a gateway notification.
SendToolName = "send_notification"
)
Variables ¶
This section is empty.
Functions ¶
func ActiveToolNames ¶
func ActiveToolNames() []string
ActiveToolNames returns the default notify tool names.
Types ¶
type SendTool ¶
SendTool sends a notification via the notification gateway defaults.
func (SendTool) Description ¶
Description explains the tool to the model.
func (SendTool) Execute ¶
func (t SendTool) Execute(ctx context.Context, id string, args map[string]any, _ tool.UpdateHandler) (msg.ToolResultMessage, error)
Execute sends the notification using global default channel and template.
func (SendTool) Parameters ¶
Parameters returns the JSON schema for tool arguments.
Click to show internal directories.
Click to hide internal directories.