Documentation
¶
Overview ¶
Package executor provides the pipeline execution engine.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Engine ¶
type Engine struct {
// contains filtered or unexported fields
}
Engine manages the lifecycle of a task runtime, enforcing single-task execution and providing state introspection.
func New ¶
New creates a new Engine for the given runtime type without initializing the underlying runtime. The runtime is lazily initialized on the first Run.
func (*Engine) Close ¶ added in v0.92.0
Close cleans up the engine's runtime resources and marks the engine as closed. It is safe to call Close multiple times; subsequent calls are no-ops.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package runtime implements pipeline task execution runtimes.
|
Package runtime implements pipeline task execution runtimes. |
|
capability
Package capability implements capability-based execution runtime.
|
Package capability implements capability-based execution runtime. |
|
docker
Package docker implements the Docker execution runtime.
|
Package docker implements the Docker execution runtime. |
|
machine
Package machine implements the machine execution runtime.
|
Package machine implements the machine execution runtime. |
|
shell
Package shell implements the shell command execution runtime.
|
Package shell implements the shell command execution runtime. |
Click to show internal directories.
Click to hide internal directories.