Documentation
¶
Overview ¶
Package capability implements capability-based execution runtime.
Index ¶
Constants ¶
const (
Prefix = "capability:"
)
Prefix identifies tasks that should be handled by the capability runtime.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Runtime ¶
type Runtime struct{}
Runtime executes tasks by invoking registered ability capabilities.
func (*Runtime) HealthCheck ¶
HealthCheck always returns nil because the capability runtime has no external dependencies to verify.
Click to show internal directories.
Click to hide internal directories.