Documentation
¶
Overview ¶
Package docker implements the Docker execution runtime.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BindMounter ¶
type BindMounter struct {
// contains filtered or unexported fields
}
BindMounter manages host-path bind mounts with an allow/deny policy.
func NewBindMounter ¶
func NewBindMounter(cfg BindConfig) *BindMounter
NewBindMounter creates a new BindMounter with the given configuration.
type KubernetesConfig ¶
type KubernetesConfig struct {
AllNamespaces string `json:"allNamespaces,omitempty"`
}
KubernetesConfig contains Kubernetes orchestrator settings
type Option ¶
type Option = func(rt *Runtime)
func WithClient ¶ added in v0.93.0
WithClient sets a pre-existing Docker client, avoiding the creation of a duplicate client when sharing one across components (e.g. VolumeMounter).
func WithConfig ¶
WithConfig sets the docker config file path for registry authentication.
func WithMounter ¶
type Runtime ¶
type Runtime struct {
// contains filtered or unexported fields
}
func NewRuntime ¶
type TmpfsMounter ¶
type TmpfsMounter struct {
}
func NewTmpfsMounter ¶
func NewTmpfsMounter() *TmpfsMounter
type VolumeMounter ¶
type VolumeMounter struct {
// contains filtered or unexported fields
}
VolumeMounter manages Docker volume lifecycle: creation on Mount, removal on Unmount.
func NewVolumeMounter ¶
func NewVolumeMounter() (*VolumeMounter, error)
NewVolumeMounter creates a VolumeMounter with its own Docker client.
func NewVolumeMounterWithClient ¶ added in v0.93.0
func NewVolumeMounterWithClient(c *client.Client) *VolumeMounter
NewVolumeMounterWithClient creates a VolumeMounter using the provided Docker client, allowing the client to be shared with the Runtime to reduce resource usage.