Documentation
¶
Overview ¶
Package rdb provides a singleton Redis client with connection pool configuration.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Client *redis.Client
Client is the singleton Redis client, provided by NewClient via fx.
Functions ¶
func BloomUnique ¶
BloomUnique filters a slice of items through a Redis bloom filter, returning only the items that are newly added (i.e. unique). The bloom filter is identified by id and expires after bloomKeyTTL.
func BloomUniqueString ¶
BloomUniqueString checks whether a single string is unique using a Redis bloom filter identified by id. Returns true if the string was newly added (unique), false if it was already seen. The bloom filter expires after bloomKeyTTL.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.